@@ -28,7 +28,10 @@ impl Filter for U32IsEqualStateFilter {
         let current_state = state_manager.get_value(self.state_index);
 
         let current_state = *match current_state {
-            Value::U32(value) => value,
+            Some(Value::U32(value)) => value,
+            None => {
+                panic!("No state value provided for u32 is equal state filter.")
+            }
             _ => {
                 panic!("Wrong state value provided for u32 is equal state filter.");
             }
@@ -63,7 +66,10 @@ impl Filter for U32IncrementStateFilter {
         let current_state = state_manager.get_value(self.state_index);
 
         let current_state = *match current_state {
-            Value::U32(value) => value,
+            Some(Value::U32(value)) => value,
+            None => {
+                panic!("No state value provided for u32 increment state filter.");
+            },
             _ => {
                 panic!("Wrong state value provided for u32 increment state filter.");
             }
